@@ -1,5 +1,5 @@
 package Crypt::Passphrase;
-$Crypt::Passphrase::VERSION = '0.013';
+$Crypt::Passphrase::VERSION = '0.014';
 use strict;
 use warnings;
 
@@ -39,12 +39,11 @@ sub import {
 }
 
 sub _load_extension {
-	my $name = shift;
-	$name =~ s/^(?!\+)/Crypt::Passphrase::/;
-	$name =~ s/^\+//;
-	(my $filename = "$name.pm") =~ s{::}{/}g;
-	require $filename;
-	return $name;
+	my $short_name = shift;
+	my $module_name = $short_name =~ s/^(\+)?/$1 ? '' : 'Crypt::Passphrase::'/re;
+	my $file_name = "$module_name.pm" =~ s{::}{/}gr;
+	require $file_name;
+	return $module_name;
 }
 
 sub _load_encoder {
@@ -57,12 +56,8 @@ sub _load_encoder {
 		my $encoder_module = _load_extension(delete $encoder_conf{module});
 		return $encoder_module->new(%encoder_conf);
 	}
-	elsif ($encoder) {
-		my $encoder_module = _load_extension($encoder);
-		return $encoder_module->new;
-	}
 	else {
-		Carp::croak('No encoder given to Crypt::Passphrase->new');
+		return _load_extension($encoder)->new;
 	}
 }
 
@@ -88,6 +83,7 @@ sub _load_validator {
 my %valid = map { $_ => 1 } qw/C D KC KD/;
 sub new {
 	my ($class, %args) = @_;
+	Carp::croak('No encoder given to Crypt::Passphrase->new') if not $args{encoder};
 	my $encoder = _load_encoder($args{encoder});
 	my @validators = map { _load_validator($_) } @{ $args{validators} };
 	my $normalization = $args{normalization} || 'C';
@@ -160,7 +156,7 @@ Crypt::Passphrase - A module for managing passwords in a cryptographically agile
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -300,6 +296,10 @@ A first-generation memory-hard algorithm, Argon2 is recommended instead if you w
 
 Your system's C<crypt> implementation. Support for various algorithms varies between platforms and platform versions, and while on some platforms it's a good backend one should not rely on this for a portable result.
 
+=item * L<Crypt::Passphrase::Pepper::Simple|Crypt::Passphrase::Pepper::Simple>
+
+A meta-encoder that adds peppering to your passwords by pre-hashing the inputs.
+
 =back
 
 =head1 INTEGRATIONS
