@@ -1,5 +1,5 @@
 package Crypt::Passphrase::System;
-$Crypt::Passphrase::System::VERSION = '0.013';
+$Crypt::Passphrase::System::VERSION = '0.014';
 use strict;
 use warnings;
 
@@ -63,7 +63,7 @@ sub new {
 sub hash_password {
 	my ($self, $password) = @_;
 	my $salt = $self->random_bytes($self->{salt_size});
-	(my $encoded_salt = encode_base64($salt, "")) =~ tr{A-Za-z0-9+/=}{./0-9A-Za-z}d;
+	my $encoded_salt = encode_base64($salt, "") =~ tr{A-Za-z0-9+/=}{./0-9A-Za-z}dr;
 	return crypt($password, "$self->{settings}$encoded_salt\$");
 }
 
@@ -105,7 +105,7 @@ Crypt::Passphrase::System - An system crypt() encoder for Crypt::Passphrase
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
